@@ -1,6 +1,6 @@
 /*********************************************************************
 This file is part of the argtable2 library.
-Copyright (C) 1998-2001,2003-2006 Stewart Heitmann
+Copyright (C) 1998-2001,2003-2007 Stewart Heitmann
 sheitmann@users.sourceforge.net
 
 The argtable2 library is free software; you can redistribute it and/or
@@ -138,6 +138,9 @@ struct arg_int* arg_intn(const char* shortopts,
     size_t nbytes;
     struct arg_int *result;
 
+	/* foolproof things by ensuring maxcount is not less than mincount */
+	maxcount = (maxcount<mincount) ? mincount : maxcount;
+
     nbytes = sizeof(struct arg_int)     /* storage for struct arg_int */
            + maxcount * sizeof(int);    /* storage for ival[maxcount] array */
 
