@@ -1,6 +1,6 @@
 /*********************************************************************
 This file is part of the argtable2 library.
-Copyright (C) 1998-2001,2003-2006 Stewart Heitmann
+Copyright (C) 1998-2001,2003-2007 Stewart Heitmann
 sheitmann@users.sourceforge.net
 
 The argtable2 library is free software; you can redistribute it and/or
@@ -502,7 +502,18 @@ int arg_parse(int argc, char **argv, void **argtable)
     endindex = arg_endindex(table);
     endtable = (struct arg_end*)table[endindex];
 
-    /* alloc space for a local copy of argv[] */
+    /* Special case of argc==0.  This can occur on Texas Instruments DSP. */
+    /* Failure to trap this case results in an unwanted NULL result from  */
+    /* the malloc for argvcopy (next code block).                         */
+    if (argc==0)
+        {
+        /* We must still perform post-parse checks despite the absence of command line arguments */
+        arg_parse_check(table,endtable);
+
+        /* Now we are finished */
+        return endtable->count;
+        }
+
     argvcopy = malloc(sizeof(char *) * argc);
     if (argvcopy)
         {
@@ -514,7 +525,7 @@ int arg_parse(int argc, char **argv, void **argtable)
         susbsequent parsing attempts.
         */
         for (i=0; i<argc; i++)
-           argvcopy[i] = argv[i];
+            argvcopy[i] = argv[i];
 
         /* parse the command line (local copy) for tagged options */
         arg_parse_tagged(argc,argvcopy,table,endtable);
@@ -533,7 +544,7 @@ int arg_parse(int argc, char **argv, void **argtable)
         {
         /* memory alloc failed */
         arg_register_error(endtable,endtable,ARG_EMALLOC,NULL);
-        }
+        }        
 
     return endtable->count;
     }
